GithubActionsJobModel class abstract

Value for model.

Available extensions
Annotations
  • @freezed
  • @formValue
  • @immutable
  • @CollectionModelPath.new("organization/:organization_id/repository/:repository_id/actions/:action_id/job", adapter: "GithubModelMasamuneAdapter.primary.modelAdapter")

Constructors

GithubActionsJobModel({int? id, int? runId, int? runAttempt, String? name, String? runnerName, int? runnerId, int? runnerGroupId, String? status, String? conclusion, @Default.new(<String>[]) List<String> labels, @jsonParam GithubUserModel? runner, @Default.new(<GithubActionsStepValue>[]) @jsonParam List<GithubActionsStepValue> steps, ModelUri? url, ModelUri? htmlUrl, ModelUri? logsUrl, ModelTimestamp? startedAt, ModelTimestamp? completedAt, @Default.new(false) bool fromServer})
Value for model.
const
factory
GithubActionsJobModel.fromJson(Map<String, Object?> json)
Convert from JSON.
factory

Properties

completedAt → ModelTimestamp?
no setterinherited
conclusion → String?
no setterinherited
copyWith → $GithubActionsJobModelCopyWith<GithubActionsJobModel>
Create a copy of GithubActionsJobModel with the given fields replaced by the non-null parameter values.
no setterinherited
fromServer → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
htmlUrl → ModelUri?
no setterinherited
id → int?
no setterinherited
labels → List<String>
no setterinherited
logsUrl → ModelUri?
no setterinherited
name → String?
no setterinherited
runAttempt → int?
no setterinherited
runId → int?
no setterinherited
runner → GithubUserModel?
no setterinherited
runnerGroupId → int?
no setterinherited
runnerId → int?
no setterinherited
runnerName → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startedAt → ModelTimestamp?
no setterinherited
status → String?
no setterinherited
steps → List<GithubActionsStepValue>
no setterinherited
url → ModelUri?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_GithubActionsJobModel value)) → TResult

Available on GithubActionsJobModel, provided by the GithubActionsJobModelPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GithubActionsJobModel value)?) → TResult?

Available on GithubActionsJobModel, provided by the GithubActionsJobModelPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GithubActionsJobModel value)?, {required TResult orElse()}) → TResult

Available on GithubActionsJobModel, provided by the GithubActionsJobModelPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int? id, int? runId, int? runAttempt, String? name, String? runnerName, int? runnerId, int? runnerGroupId, String? status, String? conclusion, List<String> labels, GithubUserModel? runner, List<GithubActionsStepValue> steps, ModelUri? url, ModelUri? htmlUrl, ModelUri? logsUrl, ModelTimestamp? startedAt, ModelTimestamp? completedAt, bool fromServer)?, {required TResult orElse()}) → TResult

Available on GithubActionsJobModel, provided by the GithubActionsJobModelPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this GithubActionsJobModel to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int? id, int? runId, int? runAttempt, String? name, String? runnerName, int? runnerId, int? runnerGroupId, String? status, String? conclusion, List<String> labels, GithubUserModel? runner, List<GithubActionsStepValue> steps, ModelUri? url, ModelUri? htmlUrl, ModelUri? logsUrl, ModelTimestamp? startedAt, ModelTimestamp? completedAt, bool fromServer)) → TResult

Available on GithubActionsJobModel, provided by the GithubActionsJobModelPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int? id, int? runId, int? runAttempt, String? name, String? runnerName, int? runnerId, int? runnerGroupId, String? status, String? conclusion, List<String> labels, GithubUserModel? runner, List<GithubActionsStepValue> steps, ModelUri? url, ModelUri? htmlUrl, ModelUri? logsUrl, ModelTimestamp? startedAt, ModelTimestamp? completedAt, bool fromServer)?) → TResult?

Available on GithubActionsJobModel, provided by the GithubActionsJobModelPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

collection → const _$GithubActionsJobModelCollectionQuery
Query for collection.
document → const _$GithubActionsJobModelDocumentQuery
Query for document.
form → const _$GithubActionsJobModelFormQuery
Query for form value.